@@ -1,10 +1,12 @@
+use strict;
+use warnings;
 use Dist::Iller::Standard;
 
 # PODNAME: Dist::Iller::Configuration
 
 class Dist::Iller::Configuration using Moose {
 
-    our $VERSION = '0.1201'; # VERSION
+    our $VERSION = '0.1202'; # VERSION
 
     has doctype => (
         is => 'ro',
@@ -202,7 +204,7 @@ Dist::Iller::Configuration
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
