@@ -1,11 +1,12 @@
+use strict;
+use warnings;
 use Dist::Iller::Standard;
 
 # PODNAME: Dist::Iller::Configuration::Plugin
 
-
 class Dist::Iller::Configuration::Plugin using Moose {
 
-    our $VERSION = '0.1201'; # VERSION
+    our $VERSION = '0.1202'; # VERSION
 
     use MooseX::StrictConstructor;
 
@@ -130,7 +131,7 @@ Dist::Iller::Configuration::Plugin
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
