@@ -1,10 +1,13 @@
+use strict;
+use warnings;
 use Dist::Iller::Standard;
 
-our $VERSION = '0.1201'; # VERSION
 # PODNAME: Dist::Iller::Doctype
 
 class Dist::Iller::Doctype using Moose {
 
+    our $VERSION = '0.1202'; # VERSION
+
     has type => (
         is => 'ro',
         isa => Enum([qw/dist weaver/]),
@@ -55,7 +58,7 @@ Dist::Iller::Doctype
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
