@@ -1,6 +1,8 @@
+use strict;
+use warnings;
 use Dist::Iller::Standard;
 
-our $VERSION = '0.1201'; # VERSION
+our $VERSION = '0.1202'; # VERSION
 # PODNAME: Dist::Iller::Role::Config
 
 role Dist::Iller::Role::Config using Moose {
@@ -57,7 +59,7 @@ Dist::Iller::Role::Config
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
