@@ -1,10 +1,13 @@
 use 5.14.0;
+use strict;
+use warnings;
 
-our $VERSION = '0.1201'; # VERSION
 
 package #
     Dist::Iller::Standard {
 
+    our $VERSION = '0.1202'; # VERSION
+
     use base 'Moops';
     use List::AllUtils();
     use Dist::Iller::Types();
@@ -47,7 +50,7 @@ Dist::Iller::Standard
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
