@@ -1,7 +1,9 @@
 use feature ':5.14';
+use strict;
+use warnings;
 use Moops;
 
-our $VERSION = '0.1201'; # VERSION
+our $VERSION = '0.1202'; # VERSION
 # PODNAME: Dist::Iller::Types
 
 library  Dist::Iller::Types
@@ -47,7 +49,7 @@ Dist::Iller::Types
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
