@@ -1,6 +1,9 @@
+use strict;
+use warnings;
+
 package Dist::Zilla::MintingProfile::DistIller::Basic;
 
-our $VERSION = '0.1201'; # VERSION
+our $VERSION = '0.1202'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
@@ -19,7 +22,7 @@ Dist::Zilla::MintingProfile::DistIller::Basic
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
