@@ -1,6 +1,9 @@
+use strict;
+use warnings;
+
 package Dist::Zilla::Plugin::DistIller::MetaGeneratedBy;
 
-our $VERSION = '0.1201'; # VERSION
+our $VERSION = '0.1202'; # VERSION
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
@@ -32,7 +35,7 @@ Dist::Zilla::Plugin::DistIller::MetaGeneratedBy
 
 =head1 VERSION
 
-Version 0.1201, released 2015-11-24.
+Version 0.1202, released 2015-11-27.
 
 =head1 SOURCE
 
